from setuptools import find_packages, setup

setup(
    name='lor_gdp_tools',
    packages=find_packages(),
    version='0.1.1',
    description='This is a utility package designed to enable data scientitists and analysts to easily access GDP data within a python environment',
    author="Damian Rumble <DRumble@laingorourke.com>"
)
